@@ -57,4 +57,14 @@ def ExploreMicrosoft(query):
 def SearchGitHub(query):
   query = query.replace(" ", "+")
   query_URL = "https://github.com/search?q=" + query
+  return query_URL
+
+def Custom(query, queryurl, spacingsymbol):
+  query = query.replace(" ", spacingsymbol)
+  query_URL = queryurl + query
+  return query_URL
+
+def SearchApple(query):
+  query = query.replace(" ", "-")
+  query_URL = "https://apple.com/search/" + query
   return query_URL
\ No newline at end of file
